StorageController class

Constructors

StorageController()

Properties

auth ↔ AuthService
latefinal
connectionStatus → Stream<ConnectionStatus>
no setter
connectivity ↔ ConnectivityService
latefinal
currentState → StorageState
no setter
hashCode → int
The hash code for this object.
no setterinherited
images ↔ ImageCacheService
latefinal
networkStatus → ConnectionStatus
no setter
prefs ↔ PrefsService
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secure ↔ SecureService
latefinal
state → Stream<StorageState>
no setter

Methods

clearAll() → Future<void>
clearByType(StorageType type) → Future<void>
dispose() → void
exportAll() → Future<Map<String, dynamic>>
getStats() → Future<Map<String, dynamic>>
importData(Map<String, dynamic> data) → Future<void>
initialize({bool enableSecure = true}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited