ImageCacheService class

Constructors

ImageCacheService()

Properties

cacheStream → Stream<Map<String, FileInfo>>
no setter
currentCache → Map<String, FileInfo>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() → Future<void>
configureCacheDuration(Duration? duration) → void
deleteImage(String url, {String? cacheKey}) → Future<void>
deleteImages(List<String> urls, {Map<String, String>? cacheKeys}) → Future<void>
dispose() → void
downloadAndCacheImage(String url, {Map<String, String>? headers, String? cacheKey}) → Future<Uint8List?>
getCachedImage(String url, {String? cacheKey}) → Future<Uint8List?>
getCacheInfo() → Future<CacheInfo>
getImage(String url, {Map<String, String>? headers, String? cacheKey, bool forceDownload = false}) → Future<Uint8List?>
getImagesMetadata() → Map<String, DateTime>
initialize() → Future<void>
isImageCached(String url, {String? cacheKey}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preloadImages(List<String> urls, {Map<String, String>? headers, Map<String, String>? cacheKeys}) → Future<void>
toString() → String
A string representation of this object.
inherited
watchImage(String url, {String? cacheKey}) → Stream<Uint8List?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited