SecureService class

Constructors

SecureService()

Properties

currentData → Map<String, dynamic>
no setter
dataStream → Stream<Map<String, dynamic>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String key) → Future<bool>
delete(String key) → Future<void>
deleteAll() → Future<void>
dispose() → void
getKeys() → Future<List<String>>
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read<T>(String key) → Future<T?>
toString() → String
A string representation of this object.
inherited
watch<T>(String key) → Stream<T?>
write(String key, dynamic value) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited