StorageState class

Constructors

StorageState({bool isInitialized = false, bool isLoading = false, String? error, int secureDataCount = 0, int prefsDataCount = 0, int imageCacheCount = 0, int imageCacheSize = 0, DateTime? lastClearedAt, StorageType? lastClearedType, DateTime? lastImportedAt, DateTime? lastExportedAt})
const

Properties

error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
imageCacheCount → int
final
imageCacheSize → int
final
isInitialized → bool
final
isLoading → bool
final
lastClearedAt → DateTime?
final
lastClearedType → StorageType?
final
lastExportedAt → DateTime?
final
lastImportedAt → DateTime?
final
prefsDataCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureDataCount → int
final

Methods

copyWith({bool? isInitialized, bool? isLoading, String? error, int? secureDataCount, int? prefsDataCount, int? imageCacheCount, int? imageCacheSize, DateTime? lastClearedAt, StorageType? lastClearedType, DateTime? lastImportedAt, DateTime? lastExportedAt}) → StorageState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited