FirestoreGatewayController class

Properties

connectionStatus Stream<ConnectionStatus>
no setter
currentMode GatewayMode
no setter
currentPendingWrites int
no setter
currentState FirestoreGatewayState
no setter
hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
no setter
isOnline bool
no setter
mode Stream<GatewayMode>
no setter
pendingWrites Stream<int>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Stream<FirestoreGatewayState>
no setter

Methods

batchWrite(dynamic updateFunction(WriteBatch batch)) Future<void>
clearCache() Future<void>
deleteDocument({required DocumentReference<Map<String, dynamic>> docRef}) Future<void>
dispose() → void
getDocument({required DocumentReference<Map<String, dynamic>> docRef}) Future<DocumentSnapshot<Map<String, dynamic>>>
getDocuments({required Query<Map<String, dynamic>> query}) Future<QuerySnapshot<Map<String, dynamic>>>
initialize({required SecureService secureService, GatewayMode mode = GatewayMode.smart}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runTransaction<T>(TransactionHandler<T> handler) Future<T>
setDocument({required DocumentReference<Map<String, dynamic>> docRef, required Map<String, dynamic> data, SetOptions? options}) Future<void>
setMode(GatewayMode mode) Future<void>
streamDocument({required DocumentReference<Map<String, dynamic>> docRef}) Stream<DocumentSnapshot<Map<String, dynamic>>>
streamDocuments({required Query<Map<String, dynamic>> query}) Stream<QuerySnapshot<Map<String, dynamic>>>
toString() String
A string representation of this object.
inherited
updateDocument({required DocumentReference<Map<String, dynamic>> docRef, required Map<String, dynamic> data}) Future<void>
waitForPendingWrites() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited