AuthService class

Constructors

AuthService()

Properties

customFields ↔ Signal<Map<String, dynamic>>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticated ↔ Computed<bool>
latefinal
isMfaCodeValid ↔ Computed<bool>
latefinal
mfaCode ↔ Signal<String?>
latefinal
mfaCodeExpiry ↔ Signal<DateTime?>
latefinal
role ↔ Signal<String?>
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ Signal<String?>
latefinal
uid ↔ Signal<String?>
latefinal

Methods

clearAuth() → Future<void>
clearMfaCode() → Future<void>
dispose() → void
export() → Map<String, dynamic>
get() → Future<Map<String, dynamic>?>
hasField(String fieldName) → bool
import(Map<String, dynamic> data) → Future<void>
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save({required String uid, required String token, String? role, String? mfaCode, DateTime? mfaCodeExpiry, Map<String, dynamic>? custom}) → Future<void>
saveMfaCode(String code, {Duration? validFor}) → Future<void>
setCustomField(String key, dynamic value) → Future<void>
toString() → String
A string representation of this object.
inherited
updateRole(String newRole) → Future<void>
updateToken(String newToken) → Future<void>
verifyMfaCode(String inputCode) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited