ConnectivityService class
Constructors
-
ConnectivityService.custom({Future<
bool> probe()?, Future<List< readInterfaces()?, Stream<ConnectivityResult> >List< interfaceChanges()?, Duration onlineInterval = const Duration(seconds: 30), Duration activeInterval = const Duration(seconds: 5), Duration minOfflineInterval = const Duration(seconds: 5), Duration maxOfflineInterval = const Duration(seconds: 10)})ConnectivityResult> >
Properties
- currentStatus → ConnectionStatus
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInternet → bool
-
no setter
-
isOnline
→ Computed<
bool> -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ Signal<
ConnectionStatus> -
final
-
statusStream
→ Stream<
ConnectionStatus> -
no setter
Methods
-
checkConnection(
) → Future< bool> -
dispose(
) → void -
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseMonitoring(
) → void -
refresh(
{Duration maxAge = Duration.zero}) → Future< bool> -
resumeMonitoring(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
touch(
) → void -
verify(
) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ConnectivityService
-
no setter