ConnectivityService class
Properties
- currentStatus → ConnectionStatus
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInternet → bool
-
no setter
-
isOnline
↔ Computed<
bool> -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
↔ Signal<
ConnectionStatus> -
latefinal
-
statusStream
→ Stream<
ConnectionStatus> -
no setter
Methods
-
checkConnection(
) → Future< bool> -
dispose(
) → void -
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseMonitoring(
) → void -
resumeMonitoring(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ConnectivityService
-
no setter